@@ -27,6 +27,10 @@ class Widget(EventHandle, Themes):
 
         self.onButtonLeftMotion(lambda event: move())
 
+    def loadSvg(self):
+        from tksvg import load
+        load(self.Me)
+
     def setOrient(self, orient):
         from tkinter import TclError
         try:
@@ -96,12 +100,12 @@ class Widget(EventHandle, Themes):
 
     def setParent(self, parnet):
         try:
-            from win32gui import SetParent
+            from Padevel import setParent
         except:
             pass
         else:
             try:
-                SetParent(self.gethWnd(), parnet.gethWnd())
+                setParent(self.gethWnd(), parnet.gethWnd())
             except:
                 pass
 
@@ -502,4 +506,7 @@ class Widget(EventHandle, Themes):
             try:
                 DevNotification(title, message, appName, appIcon, timeOut).show()
             except:
-                prError("Plyer -> Check -> Not Installed")
\ No newline at end of file
+                prError("Plyer -> Check -> Not Installed")
+
+    def quit(self):
+        self.Me.quit()
\ No newline at end of file
